@@ -3,40 +3,40 @@ App::DBBrowser::DB::Pg;
 
 use warnings;
 use strict;
-use 5.008003;
+use 5.010001;
 
 use File::Basename qw( basename );
 
 use DBI qw();
 
 use App::DBBrowser::Credentials;
+use App::DBBrowser::Opt::DBGet;
 
 
 sub new {
-    my ( $class, $info ) = @_;
-    my $self = {
-        driver       => 'Pg',
-        app_dir      => $info->{app_dir},
-        add_metadata => $info->{add_metadata},
+    my ( $class, $info, $opt ) = @_;
+    my $sf = {
+        i => $info,
+        o => $opt
     };
-    bless $self, $class;
+    bless $sf, $class;
 }
 
 
 sub get_db_driver {
-    my ( $self ) = @_;
-    return $self->{driver};
+    my ( $sf ) = @_;
+    return 'Pg';
 }
 
 
 sub env_variables {
-    my ( $self ) = @_;
+    my ( $sf ) = @_;
     return [ qw( DBI_DSN DBI_HOST DBI_PORT DBI_USER DBI_PASS ) ];
 }
 
 
 sub read_arguments {
-    my ( $self ) = @_;
+    my ( $sf ) = @_;
     return [
         { name => 'host', prompt => "Host",     secret => 0 },
         { name => 'port', prompt => "Port",     secret => 0 },
@@ -47,7 +47,7 @@ sub read_arguments {
 
 
 sub set_attributes {
-    my ( $self ) = @_;
+    my ( $sf ) = @_;
     return [
         { name => 'pg_enable_utf8', default => 2, values => [ 0, 1, -1 ] },
     ];
@@ -55,12 +55,16 @@ sub set_attributes {
 
 
 sub get_db_handle {
-    my ( $self, $db, $parameter ) = @_;
-    my $cred = App::DBBrowser::Credentials->new( { parameter => $parameter } );
+    my ( $sf, $db ) = @_;
+    my $db_opt_get = App::DBBrowser::Opt::DBGet->new( $sf->{i}, $sf->{o} );
+    my $login_data  = $db_opt_get->login_data( $db );
+    my $env_var_yes = $db_opt_get->enabled_env_vars( $db );
+    my $attributes  = $db_opt_get->attributes( $db );
+    my $cred = App::DBBrowser::Credentials->new( { login_data => $login_data, env_var_yes => $env_var_yes } );
     my $dsn;
     my $info = 'DB '. basename( $db );
-    if ( ! $parameter->{use_env_var}{DBI_DSN} || ! exists $ENV{DBI_DSN} ) {
-        $dsn = "dbi:$self->{driver}:dbname=$db";
+    if ( ! $env_var_yes->{DBI_DSN} || ! exists $ENV{DBI_DSN} ) {
+        $dsn = "dbi:$sf->{i}{driver}:dbname=$db";
         my $host = $cred->get_login( 'host', $info );
         if ( defined $host ) {
             $info .= "\n" . 'Host: ' . $host;
@@ -72,7 +76,7 @@ sub get_db_handle {
             $dsn .= ";port=$port" if length $port;
         }
     }
-    my $user   = $cred->get_login( 'user', $info );
+    my $user = $cred->get_login( 'user', $info );
     $info .= "\n" . 'User: ' . $user if defined $user;
     my $passwd = $cred->get_login( 'pass', $info );
     my $dbh = DBI->connect( $dsn, $user, $passwd, {
@@ -80,28 +84,28 @@ sub get_db_handle {
         RaiseError => 1,
         AutoCommit => 1,
         ShowErrorStatement => 1,
-        %{$parameter->{attributes}},
+        %$attributes,
     } ) or die DBI->errstr;
     return $dbh;
 }
 
 
 sub get_databases {
-    my ( $self, $parameter ) = @_;
+    my ( $sf ) = @_;
     return \@ARGV if @ARGV;
     my @regex_system_db = ( '^postgres$', '^template0$', '^template1$' );
     my $stmt = "SELECT datname FROM pg_database";
-    if ( ! $self->{add_metadata} ) {
+    if ( ! $sf->{o}{G}{metadata} ) {
         $stmt .= " WHERE " . join( " AND ", ( "datname !~ ?" ) x @regex_system_db );
     }
     $stmt .= " ORDER BY datname";
     my $info_database = 'postgres';
-    #print $self->{clear_screen};
+    #print $sf->{clear_screen};
     #print "DB: $info_database\n";
-    my $dbh = $self->get_db_handle( $info_database, $parameter );
-    my $databases = $dbh->selectcol_arrayref( $stmt, {}, $self->{add_metadata} ? () : @regex_system_db );
+    my $dbh = $sf->get_db_handle( $info_database );
+    my $databases = $dbh->selectcol_arrayref( $stmt, {}, $sf->{o}{G}{metadata} ? () : @regex_system_db );
     $dbh->disconnect(); ##
-    if ( $self->{add_metadata} ) {
+    if ( $sf->{o}{G}{metadata} ) {
         my $regexp = join '|', @regex_system_db;
         my $user_db   = [];
         my $system_db = [];
